@@ -5,6 +5,7 @@ from bitbucket_mcp.tools.memory import register_memory_tools
 from bitbucket_mcp.tools.pull_requests import register_pull_request_tools
 from bitbucket_mcp.tools.repositories import register_repository_tools
 from bitbucket_mcp.tools.search import register_search_tools
+from bitbucket_mcp.tools.users import register_user_tools
 
 __all__ = [
     "register_repository_tools",
@@ -12,4 +13,5 @@ __all__ = [
     "register_pull_request_tools",
     "register_search_tools",
     "register_memory_tools",
+    "register_user_tools",
 ]
